@@ -6,18 +6,9 @@
 #' @param color Character. Color of circle.
 #' @param line.type Character. Circle line type.
 #' @param vestry Logical. \code{TRUE} uses the 14 pumps and locations from Vestry report. \code{FALSE} uses original 13 pumps.
-#' @param subtitle Logical. Add subtitle with estimated "walking" time in seconds.
+#' @param add.subtitle Logical. Add subtitle with estimated "walking" time in seconds.
 #' @param walking.speed Numeric. Walking speed in km/hr.
-#' @param ... Additional plotting parameters.
-#' @seealso \code{\link{snowMap}},
-#' \code{\link{addIndexCase}},
-#' \code{\link{addKernelDensity}},
-#' \code{\link{addLandmarks}},
-#' \code{\link{addPlaguePit}},
-#' \code{\link{addSnow}},
-#' \code{\link{addVoronoi}}
 #' @return Adds a circle (polygon) to a graphics plot.
-#' @seealso \code{\link{addLandmarks}}
 #' @import graphics
 #' @export
 #' @examples
@@ -25,10 +16,10 @@
 #' addWhitehead()
 
 addWhitehead <- function(pump = "Broad Street", radius = 210, color = "black",
-  line.type = "solid", vestry = FALSE, subtitle = FALSE, walking.speed = 5,
-  ...) {
+  line.type = "solid", vestry = FALSE, add.subtitle = FALSE,
+  walking.speed = 5) {
 
-  r <- radius / cholera::unitMeter(1, "yard")
+  r <- radius / unitMeter(1, "yard")
   unit.base <- 100
   unit.radians <- 2 * pi / unit.base
 
@@ -79,8 +70,9 @@ addWhitehead <- function(pump = "Broad Street", radius = 210, color = "black",
   }
   lines(circumference.x, circumference.y, col = color, lty = line.type)
 
-  if (subtitle) {
-    est.time <- distanceTime(unitMeter(r, "native"), speed = walking.speed)
+  if (add.subtitle) {
+    est.time <- distanceTime(unitMeter(r, "native"),
+      walking.speed = walking.speed)
     title(sub = paste(round(est.time, 1), "secs."))
   }
 }
