@@ -1,18 +1,17 @@
 #' Compute length of selected street.
 #'
 #' @param road Character or Numeric. Road name or number. For names, the function tries to correct for case and to remove extra spaces.
-#' @param unit Character. Unit of distance: "meter", "yard" or "native". "native" returns the map's native scale. See \code{vignette("roads")} for information on conversion.
+#' @param distance.unit Character. Unit of distance: "meter", "yard" or "native". "native" returns the map's native scale. See \code{vignette("roads")} for information on conversion.
 #' @return  An R vector of length one.
-#' @seealso \code{\link{roads}}, code{\link{road.segments}}, \code{\link{streetNameLocator}}, \code{\link{streetNumberLocator}}, \code{vignette("roads")}
 #' @export
 #' @examples
 #' streetLength("Oxford Street")
 #' streetLength("oxford street")
-#' streetLength("oxford street", unit = "yard")
+#' streetLength("oxford street", distance.unit = "yard")
 
-streetLength <- function(road = "Oxford Street", unit = "meter") {
-  if (unit %in% c("meter", "yard", "native") == FALSE) {
-    stop('unit must be "meter", "yard" or "native".')
+streetLength <- function(road = "Oxford Street", distance.unit = "meter") {
+  if (distance.unit %in% c("meter", "yard", "native") == FALSE) {
+    stop('distance.unit must be "meter", "yard" or "native".')
   }
 
   if (is.character(road)) {
@@ -40,11 +39,11 @@ streetLength <- function(road = "Oxford Street", unit = "meter") {
                       as.matrix(dat[dat$id == i, c("x2", "y2")])))
   }, numeric(1L))
 
-  if (unit == "native") {
+  if (distance.unit == "native") {
     sum(distances)
-  } else if (unit == "yard") {
-    cholera::unitMeter(sum(distances), "yard")
-  } else if (unit == "meter") {
-    cholera::unitMeter(sum(distances), "meter")
+  } else if (distance.unit == "yard") {
+    unitMeter(sum(distances), "yard")
+  } else if (distance.unit == "meter") {
+    unitMeter(sum(distances), "meter")
   }
 }
