@@ -1,4 +1,5 @@
 ## ---- echo = FALSE, message = FALSE--------------------------------------
+knitr::opts_chunk$set(collapse = TRUE, comment = ">")
 library(cholera)
 
 ## ---- fig.width = 5, fig.height = 5, fig.align = "center", message = FALSE----
@@ -11,6 +12,9 @@ plot(neighborhoodVoronoi(-7))
 # print(neighborhoodVoronoi()) or
 neighborhoodVoronoi()
 
+## ------------------------------------------------------------------------
+pearsonResiduals(neighborhoodVoronoi())
+
 ## ---- fig.width = 5, fig.height = 5, fig.align = "center", message = FALSE----
 plot(neighborhoodWalking())
 
@@ -18,17 +22,15 @@ plot(neighborhoodWalking())
 # print(neighborhoodWalking()) or
 neighborhoodWalking()
 
+## ------------------------------------------------------------------------
+pearsonResiduals(neighborhoodWalking())
+
 ## ---- fig.width = 5, fig.height = 5, fig.align = "center", message = FALSE----
 plot(neighborhoodWalking(case.set = "expected"))
 
 ## ---- fig.width = 5, fig.height = 5, fig.align = "center", message = FALSE----
 plot(neighborhoodWalking(case.set = "expected"), type = "area.points")
 
-## ---- fig.width = 5, fig.height = 5, fig.align = "center", message = FALSE----
-streetNameLocator("marshall street", zoom = TRUE, highlight = FALSE,
-  add.title = FALSE, radius = 0.5)
-addNeighborhood()
-
 ## ---- fig.width = 5, fig.height = 5, fig.align = "center", message = FALSE----
 plot(neighborhoodWalking(-6))
 
